@@ -151,10 +151,11 @@ class AzureStorage(BaseStorage):
         if self.connection_string is not None:
             return BlobServiceClient.from_connection_string(self.connection_string)
 
-        account_domain = self.custom_domain or "blob.core.windows.net"
-        account_url = "{}://{}.{}".format(
-            self.azure_protocol, self.account_name, account_domain
+        account_domain = self.custom_domain or "{}.blob.core.windows.net".format(
+            self.account_name
         )
+        account_url = "{}://{}".format(self.azure_protocol, account_domain)
+
         credential = None
         if self.account_key:
             credential = self.account_key
@@ -275,8 +276,9 @@ class AzureStorage(BaseStorage):
         # azure expects time in UTC
         return datetime.utcnow() + timedelta(seconds=expire)
 
-    def url(self, name, expire=None):
+    def url(self, name, expire=None, parameters=None):
         name = self._get_valid_path(name)
+        params = parameters or {}
 
         if expire is None:
             expire = self.expiration_secs
@@ -292,7 +294,9 @@ class AzureStorage(BaseStorage):
                 account_key=self.account_key,
                 user_delegation_key=user_delegation_key,
                 permission=BlobSasPermissions(read=True),
-                expiry=expiry)
+                expiry=expiry,
+                **params
+            )
             credential = sas_token
 
         container_blob_url = self.client.get_blob_client(name).url
